@@ -18,6 +18,8 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+/* #define AUD_DEBUG 1 */
+
 #include <glib.h>
 #include <string.h>
 #include <glib.h>
@@ -32,11 +34,6 @@
 #include <sys/errno.h>
 
 #include <audacious/plugin.h>
-#include <audacious/main.h>
-#include <audacious/util.h>
-#include <audacious/playlist.h>
-#include <audacious/playlist_container.h>
-#include <audacious/strings.h>
 
 static void
 parse_extm3u_info(const gchar * info, gchar ** title, gint * length)
@@ -74,106 +71,6 @@ parse_extm3u_info(const gchar * info, gchar ** title, gint * length)
     }
 }
 
-static gchar *
-str_replace_char(gchar * str, gchar old, gchar new)
-{
-    gchar *match;
-
-    g_return_val_if_fail(str != NULL, NULL);
-
-    match = str;
-    while ((match = strchr(match, old)))
-        *match = new;
-
-    return str;
-}
-
-static gchar *
-str_replace_drive_letter(gchar * str)
-{
-    gchar *match, *match_end;
-
-    g_return_val_if_fail(str != NULL, NULL);
-
-    while ((match = strstr(str, ":\\"))) {
-        match--;
-        match_end = match + 3;
-        *match++ = '/';
-        while (*match_end)
-            *match++ = *match_end++;
-        *match = 0; /* the end of line */
-    }
-
-    return str;
-}
-
-static gchar *
-_convert_dos_path(gchar * path)
-{
-    g_return_val_if_fail(path != NULL, NULL);
-
-    /* replace drive letter with '/' */
-    str_replace_drive_letter(path);
-
-    /* replace '\' with '/' */
-    str_replace_char(path, '\\', '/');
-
-    return path;
-}
-
-static gchar *
-_construct_uri(gchar *string, const gchar *playlist_name) // uri, path and anything else
-{
-    gchar *filename = g_strdup(string);
-    gchar *tmp, *path, *tfile;
-    gchar *uri = NULL;
-
-    /* try to translate dos path */
-    _convert_dos_path(filename); /* in place replacement */
-
-    /* convert backslash to slash */
-    while ((tmp = strchr(filename, '\\')) != NULL)
-        *tmp = '/';
-
-    // make full path uri here
-    // case 1: filename is raw full path or uri
-    if (filename[0] == '/' || strstr(filename, "://")) {
-        uri = g_filename_to_uri(filename, NULL, NULL);
-        if(!uri) {
-            uri = g_strdup(filename);
-        }
-        g_free(filename);
-    }
-
-    // case 2: filename is not raw full path nor uri, playlist path is full path
-    // make full path by replacing last part of playlist path with filename. (using g_build_filename)
-    else if (playlist_name[0] == '/' || strstr(playlist_name, "://")) {
-        path = g_strdup(playlist_name);
-        tmp = strrchr(path, '/'); *tmp = '\0';
-        tmp = g_build_filename(path, filename, NULL);
-        g_free(path); g_free(filename);
-
-        // make sure we pass a 100% valid URI into the core.
-        tfile = g_filename_from_uri(tmp, NULL, NULL);
-        uri = g_filename_to_uri(tfile, NULL, NULL);
-        g_free(tfile);
-
-        if (uri)
-            g_free(tmp);
-        else
-            uri = tmp;
-    }
-
-    // case 3: filename is not raw full path nor uri, playlist path is not full path
-    // just abort.
-    else {
-        g_free(filename);
-        return NULL;
-    }
-
-    return uri;
-}
-
 static void
 playlist_load_m3u(const gchar * filename, gint pos)
 {
@@ -184,14 +81,14 @@ playlist_load_m3u(const gchar * filename, gint pos)
     gint ext_len = -1;
     gboolean is_extm3u = FALSE;
     Playlist *playlist = aud_playlist_get_active();
-    gchar *uri;
+    gchar *uri = NULL;
     
     uri = g_filename_to_uri(filename, NULL, NULL);
 
     if ((file = aud_vfs_fopen(uri ? uri : filename, "rb")) == NULL)
         return;
 
-    g_free(uri);
+    g_free(uri); uri = NULL;
 
     line = g_malloc(line_len);
     while (aud_vfs_fgets(line, line_len, file)) {
@@ -230,8 +127,10 @@ playlist_load_m3u(const gchar * filename, gint pos)
             ext_info = NULL;
         }
 
-        uri = _construct_uri(line, filename);
+        uri = aud_construct_uri(line, filename);
+        AUDDBG("uri=%s\n", uri);
 
+        /* add file only if valid uri has been constructed */
         if (uri) {
             aud_playlist_load_ins_file(playlist, uri, filename, pos, ext_title, ext_len);
 
