@@ -23,11 +23,8 @@
 #include "si_cfg.h"
 #include "si_common.h"
 #include "gtktrayicon.h"
-#include "si.xpm"
-#include <audacious/playlist.h>
-#include <audacious/main.h>
 #include <audacious/ui_fileinfopopup.h>
-#include <audacious/util.h>
+#include <audacious/plugin.h>
 #include <audacious/i18n.h>
 #include <glib.h>
 #include <gdk/gdk.h>
@@ -38,7 +35,6 @@
 # define MAX(a,b) ((a) > (b) ? (a) : (b))
 #endif
 
-
 static void si_ui_statusicon_popup_timer_start ( GtkWidget * );
 static void si_ui_statusicon_popup_timer_stop ( GtkWidget * );
 static void si_ui_statusicon_smallmenu_show ( gint x, gint y, guint button, guint32 time , gpointer );
@@ -78,7 +74,10 @@ si_ui_statusicon_cb_btpress ( GtkWidget * evbox , GdkEventButton * event )
   {
     case 1:
     {
-      si_audacious_toggle_visibility();
+      if (event->state & GDK_SHIFT_MASK)
+        audacious_drct_pl_next();
+      else
+        si_audacious_toggle_visibility();
       break;
     }
 
@@ -90,6 +89,9 @@ si_ui_statusicon_cb_btpress ( GtkWidget * evbox , GdkEventButton * event )
 
     case 3:
     {
+      if (event->state & GDK_SHIFT_MASK)
+        audacious_drct_pl_prev();
+      else{
       switch ( si_cfg.rclick_menu )
       {
         case SI_CFG_RCLICK_MENU_SMALL1:
@@ -104,6 +106,7 @@ si_ui_statusicon_cb_btpress ( GtkWidget * evbox , GdkEventButton * event )
           break;
       }
       break;
+      }
     }
   }
 
@@ -121,7 +124,7 @@ si_ui_statusicon_cb_btscroll ( GtkWidget * evbox , GdkEventScroll * event )
       switch ( si_cfg.scroll_action )
       {
         case SI_CFG_SCROLL_ACTION_VOLUME:
-          si_audacious_volume_change( 5 );
+          si_audacious_volume_change( si_cfg.volume_delta );
           break;
         case SI_CFG_SCROLL_ACTION_SKIP:
           si_audacious_playback_skip( -1 );
@@ -135,7 +138,7 @@ si_ui_statusicon_cb_btscroll ( GtkWidget * evbox , GdkEventScroll * event )
       switch ( si_cfg.scroll_action )
       {
         case SI_CFG_SCROLL_ACTION_VOLUME:
-          si_audacious_volume_change( -5 );
+          si_audacious_volume_change( -si_cfg.volume_delta );
           break;
         case SI_CFG_SCROLL_ACTION_SKIP:
           si_audacious_playback_skip( 1 );
@@ -143,6 +146,8 @@ si_ui_statusicon_cb_btscroll ( GtkWidget * evbox , GdkEventScroll * event )
       }
       break;
     }
+
+    default: ;
   }
 
   return FALSE;
@@ -334,6 +339,8 @@ si_ui_statusicon_image_update ( GtkWidget * image )
   GdkPixbuf *si_pixbuf, *si_scaled_pixbuf;
   gint size = GPOINTER_TO_INT(g_object_get_data( G_OBJECT(image) , "size" ));
   static gchar *wmname = NULL;
+  
+  AUDDBG("WM reported proposed icon size: %d\n", size);
 
   /* sometimes, KDE won't give the correct size-allocation; workaround this */
   if ( wmname == NULL )
@@ -345,8 +352,37 @@ si_ui_statusicon_image_update ( GtkWidget * image )
   }
   if ( ( size <= 1 || size > 22 ) && ( wmname != NULL ) && !strcmp("KWin",wmname) )
     size = 22;
-
-  si_pixbuf = gdk_pixbuf_new_from_xpm_data( (const char**)si_xpm );
+	GtkIconTheme *theme;
+	GtkIconInfo *info;
+	int *array;
+	int i;
+	const gchar *path;
+	gboolean scalable = FALSE;
+	gboolean catch = FALSE;
+	
+	theme = gtk_icon_theme_get_default ();
+	array = gtk_icon_theme_get_icon_sizes (theme, "audacious");
+	if (array[0] != 0) {
+		for (i = 0; array[i] != 0; i++) {
+			if (array[i] == -1)
+				scalable = TRUE;
+			if (array[i] == 22)
+				catch = TRUE;
+		}
+	}
+	g_free (array);
+	if (catch) {
+		info = gtk_icon_theme_lookup_icon (theme, "audacious", 22, GTK_ICON_LOOKUP_NO_SVG);
+		path = gtk_icon_info_get_filename (info);
+		si_pixbuf = gdk_pixbuf_new_from_file (path, NULL);
+	} else if (scalable) {
+		info = gtk_icon_theme_lookup_icon (theme, "audacious", -1, GTK_ICON_LOOKUP_FORCE_SVG);
+		path = gtk_icon_info_get_filename (info);
+		si_pixbuf = gdk_pixbuf_new_from_file (path, NULL);
+		
+	} else {
+		si_pixbuf = gdk_pixbuf_new_from_file (DATA_DIR "/images/audacious_player.xpm", NULL);
+	}
   si_scaled_pixbuf = gdk_pixbuf_scale_simple( si_pixbuf , size , size , GDK_INTERP_BILINEAR );
   gtk_image_set_from_pixbuf( GTK_IMAGE(image) , si_scaled_pixbuf );
   g_object_unref( si_pixbuf );
